@@ -11,18 +11,21 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
  *
  * Copyright 2002-2004 Todd Kulesza, Davyd Madeley
+ * Copyright 2009 Neil Williams  <linux@codehelp.co.uk>
  *
  * Authors:
  * 		Davyd Madeley <davyd@ucc.asn.au>
+ * 		Neil Williams  <linux@codehelp.co.uk>
  */
 
 #include <config.h>
 
-#include <gnome.h>
-#include <glade/glade.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
 
 #include "drivel.h"
 #include "insert_poll_dialog.h"
@@ -126,7 +129,7 @@ options_scale_changed_cb (GtkWidget *spinner, gpointer user_data);
 void
 display_insert_poll_dialog (DrivelClient *dc)
 {
-	GladeXML *xml;
+	GtkBuilder *builder;
 	DrivelPoll *dp;
 	GtkListStore *voters_store, *results_store, *type_store;
 	GtkTreeIter iter;
@@ -135,16 +138,16 @@ display_insert_poll_dialog (DrivelClient *dc)
 	dp = g_new0 (DrivelPoll, 1);
 	dp->dc = dc;
 	
-	xml = load_glade_xml ("poll_dialog");
-	if (!xml)
+	builder = load_builder_xml (NULL);
+	if (!builder)
 		return;
 
 	/* dialog */
-	dp->dialog = glade_xml_get_widget (xml, "poll_dialog");
+	dp->dialog = GTK_WIDGET(gtk_builder_get_object (builder, "poll_dialog"));
 	gtk_window_set_transient_for (GTK_WINDOW (dp->dialog), GTK_WINDOW (dc->current_window));
 	drivel_push_current_window (dc, dp->dialog);
 	/* the name of the poll */
-	dp->poll_name = glade_xml_get_widget (xml, "poll_name");
+	dp->poll_name = GTK_WIDGET(gtk_builder_get_object (builder, "poll_name"));
 
 	/* voters */
 	voters_store = gtk_list_store_new (1, G_TYPE_STRING);
@@ -152,7 +155,7 @@ display_insert_poll_dialog (DrivelClient *dc)
 	gtk_list_store_set (voters_store, &iter, 0, _("All users"), -1);
 	gtk_list_store_append (voters_store, &iter);
 	gtk_list_store_set (voters_store, &iter, 0, _("Friends"), -1);
-	dp->poll_voters = glade_xml_get_widget (xml, "poll_votors");
+	dp->poll_voters = GTK_WIDGET(gtk_builder_get_object (builder, "poll_votors"));
 	gtk_combo_box_set_model (GTK_COMBO_BOX (dp->poll_voters), GTK_TREE_MODEL (voters_store));
 	gtk_cell_layout_clear (GTK_CELL_LAYOUT (dp->poll_voters));
 	renderer = gtk_cell_renderer_text_new ();
@@ -170,7 +173,7 @@ display_insert_poll_dialog (DrivelClient *dc)
 	gtk_list_store_set (results_store, &iter, 0, _("Friends"), -1);
 	gtk_list_store_append (results_store, &iter);
 	gtk_list_store_set (results_store, &iter, 0, _("None"), -1);
-	dp->poll_results = glade_xml_get_widget (xml, "poll_results");
+	dp->poll_results = GTK_WIDGET(gtk_builder_get_object (builder, "poll_results"));
 	gtk_combo_box_set_model (GTK_COMBO_BOX (dp->poll_results), GTK_TREE_MODEL (results_store));
 	gtk_cell_layout_clear (GTK_CELL_LAYOUT (dp->poll_results));
 	renderer = gtk_cell_renderer_text_new ();
@@ -183,7 +186,7 @@ display_insert_poll_dialog (DrivelClient *dc)
 	/* poll structure */
 	/* structure in the tree, enum-ed type, an image for that type, the question or answer, 3 ints */
 	dp->poll_store = gtk_tree_store_new (6, G_TYPE_INT, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT);
-	dp->poll_structure = glade_xml_get_widget (xml, "poll_structure");
+	dp->poll_structure = GTK_WIDGET(gtk_builder_get_object (builder, "poll_structure"));
 	gtk_tree_view_set_model (GTK_TREE_VIEW (dp->poll_structure), GTK_TREE_MODEL (dp->poll_store));
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (dp->poll_structure), -1,
@@ -197,20 +200,20 @@ display_insert_poll_dialog (DrivelClient *dc)
 			gtk_tree_view_get_column (GTK_TREE_VIEW (dp->poll_structure), 1));
 	
 	/* options tables & boxes*/
-	dp->options_main = glade_xml_get_widget (xml, "poll_question_options_main_table");
-	dp->options_textentry = glade_xml_get_widget (xml, "poll_question_options_textentry_table");
-	dp->options_scale = glade_xml_get_widget (xml, "poll_question_options_scale_box");
-	dp->options_answer = glade_xml_get_widget (xml, "poll_question_options_answer_table");
+	dp->options_main = GTK_WIDGET(gtk_builder_get_object (builder, "poll_question_options_main_table"));
+	dp->options_textentry = GTK_WIDGET(gtk_builder_get_object (builder, "poll_question_options_textentry_table"));
+	dp->options_scale = GTK_WIDGET(gtk_builder_get_object (builder, "poll_question_options_scale_box"));
+	dp->options_answer = GTK_WIDGET(gtk_builder_get_object (builder, "poll_question_options_answer_table"));
 
 	/* stuff from the options table */
-	dp->options_main_question = glade_xml_get_widget (xml, "poll_question_options_question");
-	dp->options_main_type = glade_xml_get_widget (xml, "poll_question_options_type");
-	dp->options_textentry_fieldsize = glade_xml_get_widget (xml, "poll_questions_options_textfieldsize");
-	dp->options_textentry_maxlength = glade_xml_get_widget (xml, "poll_questions_options_maxtextlength");
-	dp->options_scale_from = glade_xml_get_widget (xml, "poll_questions_options_scale_from");
-	dp->options_scale_to = glade_xml_get_widget (xml, "poll_questions_options_scale_to");
-	dp->options_scale_by = glade_xml_get_widget (xml, "poll_questions_options_scale_by");
-	dp->options_answer_text = glade_xml_get_widget (xml, "poll_question_options_answer");
+	dp->options_main_question = GTK_WIDGET(gtk_builder_get_object (builder, "poll_question_options_question"));
+	dp->options_main_type = GTK_WIDGET(gtk_builder_get_object (builder, "poll_question_options_type"));
+	dp->options_textentry_fieldsize = GTK_WIDGET(gtk_builder_get_object (builder, "poll_questions_options_textfieldsize"));
+	dp->options_textentry_maxlength = GTK_WIDGET(gtk_builder_get_object (builder, "poll_questions_options_maxtextlength"));
+	dp->options_scale_from = GTK_WIDGET(gtk_builder_get_object (builder, "poll_questions_options_scale_from"));
+	dp->options_scale_to = GTK_WIDGET(gtk_builder_get_object (builder, "poll_questions_options_scale_to"));
+	dp->options_scale_by = GTK_WIDGET(gtk_builder_get_object (builder, "poll_questions_options_scale_by"));
+	dp->options_answer_text = GTK_WIDGET(gtk_builder_get_object (builder, "poll_question_options_answer"));
 	/* fleshing out the type list */
 	type_store = gtk_list_store_new (2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
 	gtk_list_store_append (type_store, &iter);
@@ -238,17 +241,17 @@ display_insert_poll_dialog (DrivelClient *dc)
 	gtk_combo_box_set_active (GTK_COMBO_BOX (dp->options_main_type), POLL_TYPE_COMBO);
 
 	/* buttons */
-	dp->add_question_button = glade_xml_get_widget (xml, "poll_add_question_button");
+	dp->add_question_button = GTK_WIDGET(gtk_builder_get_object (builder, "poll_add_question_button"));
 	gtk_button_set_use_stock (GTK_BUTTON (dp->add_question_button), TRUE);
-	dp->add_answer_button = glade_xml_get_widget (xml, "poll_add_answer_button");
+	dp->add_answer_button = GTK_WIDGET(gtk_builder_get_object (builder, "poll_add_answer_button"));
 	gtk_button_set_use_stock (GTK_BUTTON (dp->add_answer_button), TRUE);
-	dp->delete_item_button = glade_xml_get_widget (xml, "poll_delete_item_button");
-	dp->help_button = glade_xml_get_widget (xml, "poll_help_button");
-	dp->cancel_button = glade_xml_get_widget (xml, "poll_cancel_button");
-	dp->insert_button = glade_xml_get_widget (xml, "poll_insert_button");
+	dp->delete_item_button = GTK_WIDGET(gtk_builder_get_object (builder, "poll_delete_item_button"));
+	dp->help_button = GTK_WIDGET(gtk_builder_get_object (builder, "poll_help_button"));
+	dp->cancel_button = GTK_WIDGET(gtk_builder_get_object (builder, "poll_cancel_button"));
+	dp->insert_button = GTK_WIDGET(gtk_builder_get_object (builder, "poll_insert_button"));
 	gtk_button_set_use_stock (GTK_BUTTON (dp->insert_button), TRUE);
-	dp->up_button = glade_xml_get_widget (xml, "poll_up_button");
-	dp->down_button = glade_xml_get_widget (xml, "poll_down_button");
+	dp->up_button = GTK_WIDGET(gtk_builder_get_object (builder, "poll_up_button"));
+	dp->down_button = GTK_WIDGET(gtk_builder_get_object (builder, "poll_down_button"));
 
 	g_signal_connect (G_OBJECT (dp->add_question_button), "clicked",
 			G_CALLBACK (add_question_cb), dp);
@@ -372,24 +375,24 @@ static GdkPixbuf
 
 	switch (type) {
 		case POLL_TYPE_COMBO:
-			pixmapfile = g_strdup (DATADIR G_DIR_SEPARATOR_S "pixmaps"
-					G_DIR_SEPARATOR_S "drivel" G_DIR_SEPARATOR_S "combobox.xpm");
+			pixmapfile = g_strdup (DATADIR G_DIR_SEPARATOR_S PACKAGE
+					G_DIR_SEPARATOR_S GLADE G_DIR_SEPARATOR_S "combobox.xpm");
 			break;
 		case POLL_TYPE_RADIO:
-			pixmapfile = g_strdup (DATADIR G_DIR_SEPARATOR_S "pixmaps"
-					G_DIR_SEPARATOR_S "drivel" G_DIR_SEPARATOR_S "radiobutton.xpm");
+			pixmapfile = g_strdup (DATADIR G_DIR_SEPARATOR_S PACKAGE
+					G_DIR_SEPARATOR_S GLADE G_DIR_SEPARATOR_S "radiobutton.xpm");
 			break;
 		case POLL_TYPE_CHECK:
-			pixmapfile = g_strdup (DATADIR G_DIR_SEPARATOR_S "pixmaps"
-					G_DIR_SEPARATOR_S "drivel" G_DIR_SEPARATOR_S "checkbutton.xpm");
+			pixmapfile = g_strdup (DATADIR G_DIR_SEPARATOR_S PACKAGE
+					G_DIR_SEPARATOR_S GLADE G_DIR_SEPARATOR_S "checkbutton.xpm");
 			break;
 		case POLL_TYPE_ENTRY:
-			pixmapfile = g_strdup (DATADIR G_DIR_SEPARATOR_S "pixmaps"
-					G_DIR_SEPARATOR_S "drivel" G_DIR_SEPARATOR_S "entry.xpm");
+			pixmapfile = g_strdup (DATADIR G_DIR_SEPARATOR_S PACKAGE
+					G_DIR_SEPARATOR_S GLADE G_DIR_SEPARATOR_S "entry.xpm");
 			break;
 		case POLL_TYPE_SCALE:
-			pixmapfile = g_strdup (DATADIR G_DIR_SEPARATOR_S "pixmaps"
-					G_DIR_SEPARATOR_S "drivel" G_DIR_SEPARATOR_S "hscale.xpm");
+			pixmapfile = g_strdup (DATADIR G_DIR_SEPARATOR_S PACKAGE
+					G_DIR_SEPARATOR_S GLADE G_DIR_SEPARATOR_S "hscale.xpm");
 			break;
 		case POLL_TYPE_NONE:
 		case POLL_TYPE_ANSWER:
