@@ -11,7 +11,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
  *
  * Copyright 2002 Todd Kulesza
  *
@@ -24,16 +25,30 @@
 
 #include <config.h>
 
+#include "soup-xmlrpc-message.h"
+
 #include "drivel_request.h"
 #include "drivel.h"
 
-/* add a network request to the queue for processing */
+/* Add a SoupMessage to the queue for processing */
 void
-net_enqueue_request (DrivelClient *dc, DrivelRequest *dr);
+net_enqueue_msg (SoupMessage *msg);
 
-/* start the network thread */
+void
+net_requeue_msg (SoupMessage *msg);
+
+/* Check for an error response */
+SoupXmlrpcResponse*
+net_msg_get_response (SoupXmlrpcMessage *msg);
+
+/* start the network session */
 gint
-net_start_thread (DrivelClient *dc);
+net_start_session (void);
+
+/* put a translated message in the statusbar, telling
+ * the user what we are doing. */
+void
+update_status_msg (DrivelRequestType type);
 
 /* send a ping to technorati */
 void
